@@ -4,4 +4,6 @@ from . import backUpVals, restoreMethods
 def restoreEpics(bak=backUpVals):
     print('Restoring channel values...')
     for ii in range(len(bak)-1, -1, -1):
-        restoreMethods[bak[ii]['type']](bak[ii])
+        for ele in bak.values():
+            if ii == ele['sno']:
+                restoreMethods[ele['type']](ele)
